# Examples

These sections include examples of using `UNIQUE` on publicly-available data.

:::{toctree}
:maxdepth: 1
notebooks/california_housing/california_housing.ipynb
notebooks/LogD_public/LogD_RFmfp.ipynb
:::
